Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(542)

Unified Diff: chrome/browser/win/jumplist.cc

Issue 2811003002: Experiment with USER_VISIBLE priority for update_jumplisticons_task_runner_ (Closed)
Patch Set: Update function names temporarily for UMA metric tracking. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/win/jumplist.h ('k') | chrome/browser/win/jumplist_file_util.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/win/jumplist.cc
diff --git a/chrome/browser/win/jumplist.cc b/chrome/browser/win/jumplist.cc
index 5f464ca058834ee9aa1d12a882ae92f73f650bd7..071087a3db853eaa28f52a2a835f809db9bf2b44 100644
--- a/chrome/browser/win/jumplist.cc
+++ b/chrome/browser/win/jumplist.cc
@@ -231,10 +231,11 @@ bool UpdateJumpList(const wchar_t* app_id,
}
// Updates the jumplist, once all the data has been fetched.
-void RunUpdateJumpList(IncognitoModePrefs::Availability incognito_availability,
- const std::wstring& app_id,
- const base::FilePath& icon_dir,
- base::RefCountedData<JumpListData>* ref_counted_data) {
+void RunUpdateJumpListUserVisiblePriority(
gab 2017/04/11 20:25:31 Don't rename methods just for this (same for other
chengx 2017/04/11 21:09:28 This CL will be included in the Canary build tomor
gab 2017/04/12 19:25:47 I disagree. 1) UMA has version filters, you shoul
+ IncognitoModePrefs::Availability incognito_availability,
+ const std::wstring& app_id,
+ const base::FilePath& icon_dir,
+ base::RefCountedData<JumpListData>* ref_counted_data) {
JumpListData* data = &ref_counted_data->data;
ShellLinkItemList local_most_visited_pages;
ShellLinkItemList local_recently_closed_pages;
@@ -284,7 +285,7 @@ JumpList::JumpList(Profile* profile)
task_id_(base::CancelableTaskTracker::kBadTaskId),
update_jumplisticons_task_runner_(base::CreateCOMSTATaskRunnerWithTraits(
base::TaskTraits()
- .WithPriority(base::TaskPriority::BACKGROUND)
+ .WithPriority(base::TaskPriority::USER_VISIBLE)
.WithShutdownBehavior(
base::TaskShutdownBehavior::CONTINUE_ON_SHUTDOWN)
.MayBlock())),
@@ -507,7 +508,7 @@ void JumpList::StartLoadingFavicon() {
if (!waiting_for_icons) {
// No more favicons are needed by the application JumpList. Schedule a
- // RunUpdateJumpList call.
+ // RunUpdateJumpListUserVisiblePriority call.
PostRunUpdate();
return;
}
@@ -533,7 +534,8 @@ void JumpList::OnFaviconDataAvailable(
JumpListData* data = &jumplist_data_->data;
base::AutoLock auto_lock(data->list_lock_);
// Attach the received data to the ShellLinkItem object.
// This data will be decoded by the RunUpdateJumpList method.
if (!image_result.image.IsEmpty() && !data->icon_urls_.empty() &&
data->icon_urls_.front().second.get()) {
gfx::ImageSkia image_skia = image_result.image.AsImageSkia();
@@ -594,13 +596,15 @@ void JumpList::DeferredRunUpdate() {
// Post a task to delete the content in JumpListIcons folder and log the
// results to UMA.
update_jumplisticons_task_runner_->PostTask(
- FROM_HERE, base::Bind(&DeleteDirectoryContentAndLogResults, icon_dir_,
- kFileDeleteLimit));
+ FROM_HERE,
+ base::Bind(&DeleteDirectoryContentAndLogResultsUserVisiblePriority,
+ icon_dir_, kFileDeleteLimit));
// Post a task to update the jumplist used by the shell.
update_jumplisticons_task_runner_->PostTask(
- FROM_HERE, base::Bind(&RunUpdateJumpList, incognito_availability, app_id_,
- icon_dir_, base::RetainedRef(jumplist_data_)));
+ FROM_HERE,
+ base::Bind(&RunUpdateJumpListUserVisiblePriority, incognito_availability,
+ app_id_, icon_dir_, base::RetainedRef(jumplist_data_)));
// Post a task to delete JumpListIconsOld folder and log the results to UMA.
base::FilePath icon_dir_old = icon_dir_.DirName().Append(
« no previous file with comments | « chrome/browser/win/jumplist.h ('k') | chrome/browser/win/jumplist_file_util.h » ('j') | no next file with comments »
@@ -533,7 +534,8 @@ void JumpList::OnFaviconDataAvailable(
base::AutoLock auto_lock(data->list_lock_);
// Attach the received data to the ShellLinkItem object.
- // This data will be decoded by the RunUpdateJumpList method.
+ // This data will be decoded by the RunUpdateJumpListUserVisiblePriority
+ // method.
if (!image_result.image.IsEmpty() && !data->icon_urls_.empty() &&
data->icon_urls_.front().second.get()) {

Powered by Google App Engine
This is Rietveld 408576698